@@ -1900,7 +1900,7 @@ class Update(MethodsInterface):
 
     def set_migration_mode(self, val=True):
         val_to_write = Variable.On if val else Variable.Off
-        self.clVars.Set("cl_update_use_migration_host", val_to_write)
+        self.clVars.Set("update.cl_update_use_migration_host", val_to_write)
         return True
 
 
@@ -2148,7 +2148,7 @@ class Update(MethodsInterface):
         """
         Проверка для переключения на миграционный хост при ошибке валидации выбранного бинхоста
         """
-        if self.clVars.GetBool("cl_update_use_migration_host"):
+        if self.clVars.GetBool("update.cl_update_use_migration_host"):
             self.clVars.Set('cl_update_save_cur_binhost', self.clVars.Get('cl_update_binhost'))
             return True
         raise UpdateError(_("Something goes wrong while validating chosen binhost"))
