@@ -47,72 +47,32 @@ class ClUpdateProfileAction(Action):
          'method': 'Update.migrateCacheRepository('
                    'cl_update_profile_url,cl_update_profile_branch,'
                    'cl_update_profile_storage)',
-         'message': __("Repository transfer"),
-         'condition': lambda Get: not (
-             Get('cl_update_profile_storage').is_local(
-                 Get('cl_update_profile_url'),
-                 Get('cl_update_profile_branch'))) and Get('cl_update_profile_check_sync_allowed')
-         },
-        {'name': 'reconfigure_vars1',
-         'method': 'Update.invalidateVariables("cl_update_profile_storage")',
-         'depend': Tasks.has('migrate_repository')
-         },
-        {'name': 'check_datavars',
-         'error': _("Profile not found in master"),
-         'condition': lambda Get: not Get('update.cl_update_profile_datavars')
-         },
-        {'name': 'drop_binhosts',
-         'method': 'Update.drop_binhosts(update.cl_update_profile_datavars)'
-         },
-        {'name': 'reconfigure_vars',
-         'method': 'Update.reconfigureProfileVars(cl_update_profile_datavars,'
-                          'cl_chroot_path)'
-         },
-        {'name': 'reps_synchronization',
-         'group': __("Repositories synchronization"),
+         'condition': lambda Get: Get('cl_update_profile_url')},
+        {'name': 'profile_from_url',
+         'group': __('setting up from url'),
          'tasks': [
-             {'name': 'sync_reps',
-              'foreach': 'cl_update_profile_sync_rep',
-              'message': __("Checking {eachvar:capitalize} updates"),
-              'method': 'Update.syncRepositories(eachvar)',
-              'condition': lambda Get: Get('cl_update_profile_check_sync_allowed')
-              },
-             {'name': 'sync_reps:regen_cache',
-              'foreach': 'cl_update_sync_overlay_rep',
-              'message': __("Updating the {eachvar:capitalize} repository cache"),
-              'essential': False,
-              'method': 'Update.regenCache(eachvar)',
-              'condition': (
-                  lambda Get: (Get('cl_update_outdate_set') == 'on' and
-                               Get('cl_update_metadata_force') != 'skip' or
-                               Get('cl_update_metadata_force') == 'force'))
-              },
-             {'name': 'emerge_metadata',
-              'message': __("Metadata transfer"),
-              'method': 'Update.emergeMetadata()',
-              'condition': (
-                  lambda Get: (Get('cl_update_outdate_set') == 'on' and
-                               Get('cl_update_metadata_force') != 'skip' or
-                               Get('cl_update_metadata_force') == 'force'))
-              },
-             {'name': 'eix_update',
-              'message': __("Updating the eix cache for "
-                            "{cl_update_eix_repositories}"),
-              'method': 'Update.eixUpdate(cl_repository_name)',
-              'condition': (
-                  lambda Get: (Get('cl_update_outdate_set') == 'on' and
-                               Get('cl_update_eixupdate_force') != 'skip' or
-                               Get('cl_update_eixupdate_force') == 'force'))
-              },
-             # сообщение удачного завершения при обновлении репозиториев
-             {'name': 'success_syncrep',
-              'message': __("Synchronization finished"),
-              'depend': (Tasks.success() & Tasks.has_any("sync_reps",
-                                                         "sync_other_reps",
-                                                         "emerge_metadata",
-                                                         "eix_update")),
-              }
-         ]
+            {'message': __("Repository transfer"),
+             'condition': lambda Get: not (
+                 Get('cl_update_profile_storage').is_local(
+                     Get('cl_update_profile_url'),
+                     Get('cl_update_profile_branch'))) and Get('cl_update_profile_check_sync_allowed'),
+             },
+            {'name': 'reconfigure_vars1',
+             'method': 'Update.invalidateVariables("cl_update_profile_storage")',
+             },
+            {'name': 'check_datavars',
+             'error': _("Profile not found in master"),
+             'condition': lambda Get: not Get('update.cl_update_profile_datavars'),
+             },
+            {'name': 'drop_binhosts',
+             'method': 'Update.drop_binhosts(update.cl_update_profile_datavars)',
+             },
+            {'name': 'reconfigure_vars',
+             'method': 'Update.reconfigureProfileVars(cl_update_profile_datavars,'
+                              'cl_chroot_path)',
+             },
+         ],
+         'depend': Tasks.has('migrate_repository')
          },
         {'name': 'reps_synchronization',
          'group': __("Setting up the profile"),
